<!DOCTYPE html>
<html lang="en">

<head>
<meta name="viewport" content="width=device-width, initial-scale=1">
<meta charset="UTF-8" />
</head>

<body>

<h1>Trust Report: {{model_name}}</h1>
<div style="border:solid black 1px; padding: 5px; margin: 5px" class="panel">
<h2>Configuration details</h2>
<p>Filename: {{reportfile}}</p>
<p>Evaluation ID: {{run_uuid}}</p>
<p>Model name: {{model_name}}</p>
<p>Evaluation started: {{start_time}}</p>
<p>Evaluation ended: {{end_time}}</p>
<p>Created by: {{created_by}}</p>
<p>Total tests: {{total_test_count}}</p>
<p>Completed tests: {{completed_test_count}}</p>
<p>Tests with errors: {{error_test_count}}</p>
</div>

<br>

{{ results | safe}}

</body>

<p style="height:400px; padding-top: 100px">
generated with <a href="https://vijil.ai">Vijil</a>
</p>

</html>